Crate griffin_core

Crate griffin_core 

This crate contains all the fundamental building blocks for the Griffin ledger, runtime, and wallet.

It was initially based on tuxedo_core, and it now includes a clone of six crates from the Pallas suite, with modifications in order to be used in a no-std setting.

The Core main purpose is to bring the Griffin node to life. The node is based on Substrate / Polkadot SDK, and the instructions to make it run can be found here.

Modules

checks_interface
Suplementary functions to perform ledger checks on Griffin transactions by using tools available in Pallas.
genesis
Utilities for blockchainchain genesis.
h224
Implementation of Polkadot-friendly 28-byte hash H224
pallas_addresses
(Brought from the Pallas suite, no-std version.)
pallas_applying
(Brought from the Pallas suite, no-std version.)
pallas_codec
(Brought from the Pallas suite, no-std version.)
pallas_crypto
(Brought from the Pallas suite, no-std version.)
pallas_interface
Interface between Griffin and Pallas Transaction types.
pallas_primitives
(Brought from the Pallas suite, no-std version.)
pallas_traverse
(Brought from the Pallas suite, no-std version.)
support_macros
These macros were copied from frame-support.
types
Types used to construct Griffin transactions.
uplc
utxo_set
UTxO interface to storage.

Macros

ensure
Evaluate $x:expr and if not true return Err($y:expr).
fail
Return Err of the expression: return Err($expression);.

Structs

Executive
The executive is in charge of validating transactions for admittance in the pool and in blocks. It is in charge of executing transactions, i.e., applying them to the ledger.

Constants

EXTRINSIC_KEY
A transient storage key that will hold the list of extrinsics that have been applied so far. This key is cleared before the end of the block.
HEIGHT_KEY
A storage key that will store the block height during and after execution. This allows the block number to be available in the runtime even during off-chain api calls.
MILLI_SECS_PER_SLOT
The Aura slot duration. When things are working well, this will also be the block time.
ZERO_SLOT
A storage key that will store the slot number of the first block in the chain.
ZERO_TIME
A storage key that will store the start POSIX time of ZERO_SLOT, in milliseconds.