Program

Struct Program 

pub struct Program<T> {
    pub version: (usize, usize, usize),
    pub term: Term<T>,
}
This represents a program in Untyped Plutus Core. A program contains a version tuple and a term. It is generic because Term requires a generic type.

Fields

version: (usize, usize, usize)term: Term<T>

Implementations

Source

impl<T> Program<T>
where T: Clone,

pub fn apply(&self, program: &Self) -> Self

We use this to apply the validator to Datum, then redeemer, then ScriptContext. If datum is even necessary (i.e. minting policy).

pub fn apply_data(&self, plutus_data: PlutusData) -> Self

A convenient and faster version that apply_term since the program doesn’t need to be re-interned (constant Data do not introduce new bindings).

Source

impl Program<Name>

pub fn apply_term(&self, term: &Term<Name>) -> Self

We use this to apply the validator to Datum, then redeemer, then ScriptContext. If datum is even necessary (i.e. minting policy).

pub fn to_debruijn(self) -> Result<Program<DeBruijn>, Error>

A convenient method to convery named programs to debruijn programs.

pub fn to_named_debruijn(self) -> Result<Program<NamedDeBruijn>, Error>

A convenient method to convery named programs to named debruijn programs.

Source

impl Program<DeBruijn>

pub fn address( &self, network: Network, delegation: ShelleyDelegationPart, plutus_version: &Language, ) -> ShelleyAddress

Source

impl Program<NamedDeBruijn>

pub fn eval(self, initial_budget: ExBudget) -> EvalResult

pub fn eval_version( self, initial_budget: ExBudget, version: &Language, ) -> EvalResult

Evaluate a Program as a specific PlutusVersion

pub fn eval_as( self, version: &Language, costs: &[i64], initial_budget: Option<&ExBudget>, ) -> EvalResult

Source

impl Program<DeBruijn>

pub fn eval(&self, initial_budget: ExBudget) -> EvalResult

pub fn eval_version( self, initial_budget: ExBudget, version: &Language, ) -> EvalResult

Source

impl<'b, T> Program<T>
where T: Binder<'b> + Debug,

pub fn from_cbor( bytes: &'b [u8], buffer: &'b mut Vec<u8>, ) -> Result<Self, Error>

pub fn from_flat(bytes: &'b [u8]) -> Result<Self, Error>

pub fn from_hex( hex_str: &str, cbor_buffer: &'b mut Vec<u8>, flat_buffer: &'b mut Vec<u8>, ) -> Result<Self, Error>

pub fn to_cbor(&self) -> Result<Vec<u8>, Error>

Convert a program to cbor bytes.

note: The cbor bytes of a program are merely the flat bytes of the program encoded as cbor bytes.

Examples
use uplc::ast::{Program, Name, Term};

let term = Term::var("x").lambda("x");
let program = Program { version: (1, 0, 0), term };

assert_eq!(
    program.to_debruijn().unwrap().to_cbor().unwrap(),
    vec![
        0x46, 0x01, 0x00, 0x00,
        0x20, 0x01, 0x01
    ],
);
pub fn to_flat(&self) -> Result<Vec<u8>, Error>

Convert a program to a flat bytes.

note: Convenient so that people don’t need to depend on the flat crate directly to call programs flat function.

Examples
use uplc::ast::{Program, Name, Term};

let term = Term::var("x").lambda("x");
let program = Program { version: (1, 0, 0), term };

assert_eq!(
    program
        .to_debruijn()
        .unwrap()
        .to_flat()
        .unwrap(),
    vec![
        0x01, 0x00, 0x00,
        0x20, 0x01, 0x01
    ],
);
pub fn to_hex(&self) -> Result<String, Error>

Convert a program to hex encoded cbor bytes

Examples
use uplc::ast::{Program, Name, Term};

let term = Term::var("x").lambda("x");
let program = Program { version: (1, 0, 0), term };

assert_eq!(
    program.to_debruijn().unwrap().to_hex().unwrap(),
    "46010000200101".to_string(),
);
Source

impl Program<Name>

pub fn run_once_pass(self) -> Self

pub fn multi_pass(self) -> (Self, Context)

pub fn run_one_opt( self, inline_lambda: bool, with: &mut impl FnMut(Option<usize>, &mut Term<Name>, Vec<Args>, &Scope, &mut Context), ) -> Self

pub fn clean_up_no_inlines(self) -> Self

pub fn afterwards(self) -> Self

pub fn builtin_curry_reducer(self) -> Self

pub fn split_body_lambda_reducer(self) -> Self