This crate contains all the fundamental building blocks for the Griffin ledger, runtime, and wallet.
It was initially based on
tuxedo_core,
and it now includes a clone of six crates from the
Pallas suite, with modifications in
order to be used in a no-std setting.
The Core main purpose is to bring the Griffin node to life. The node is based on Substrate / Polkadot SDK, and the instructions to make it run can be found here.
Modules
- checks_
interface - Suplementary functions to perform ledger checks on Griffin transactions by using tools available in Pallas.
- genesis
- Utilities for blockchainchain genesis.
- h224
- Implementation of Polkadot-friendly 28-byte hash
H224 - pallas_
addresses - (Brought from the Pallas suite,
no-stdversion.) - pallas_
applying - (Brought from the Pallas suite,
no-stdversion.) - pallas_
codec - (Brought from the Pallas suite,
no-stdversion.) - pallas_
crypto - (Brought from the Pallas suite,
no-stdversion.) - pallas_
interface - Interface between Griffin and Pallas Transaction types.
- pallas_
primitives - (Brought from the Pallas suite,
no-stdversion.) - pallas_
traverse - (Brought from the Pallas suite,
no-stdversion.) - support_
macros - These macros were copied from
frame-support. - types
- Types used to construct Griffin transactions.
- uplc
- utxo_
set - UTxO interface to storage.
Macros
- ensure
- Evaluate
$x:exprand if not true returnErr($y:expr). - fail
- Return Err of the expression:
return Err($expression);.
Structs
- Executive
- The executive is in charge of validating transactions for admittance in the pool and in blocks. It is in charge of executing transactions, i.e., applying them to the ledger.
Constants
- EXTRINSIC_
KEY - A transient storage key that will hold the list of extrinsics that have been applied so far. This key is cleared before the end of the block.
- HEIGHT_
KEY - A storage key that will store the block height during and after execution. This allows the block number to be available in the runtime even during off-chain api calls.
- MILLI_
SECS_ PER_ SLOT - The Aura slot duration. When things are working well, this will also be the block time.
- ZERO_
SLOT - A storage key that will store the slot number of the first block in the chain.
- ZERO_
TIME - A storage key that will store the start POSIX time of ZERO_SLOT, in milliseconds.